traitsui\.extras package
========================

Submodules
----------

.. toctree::

   traitsui.extras.api
   traitsui.extras.checkbox_column
   traitsui.extras.demo
   traitsui.extras.edit_column
   traitsui.extras.has_dynamic_views
   traitsui.extras.progress_column
   traitsui.extras.saving

Module contents
---------------

.. automodule:: traitsui.extras
    :members:
    :undoc-members:
    :show-inheritance:
